sqlobject.tests.test_ForeignKey_cascade module — SQLObject 3.9.1 documentation

# sqlobject.tests.test_ForeignKey_cascade module

class `sqlobject.tests.test_ForeignKey_cascade.` `SOTestMessageCascadeFalse`(**kw)

  Bases: `sqlobject.main.SQLObject`

  property `body`
  `j` = so_test_message_cascade_false
  `q` = so_test_message_cascade_false
  property `recipient`
  property `recipientID`
  property `sender`
  property `senderID`
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_ForeignKey_cascade.SOTestMessageCascadeFalse`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'so_test_message_cascade_false'

class `sqlobject.tests.test_ForeignKey_cascade.` `SOTestMessageCascadeMixed`(**kw)

  Bases: `sqlobject.main.SQLObject`

  property `body`
  `j` = so_test_message_cascade_mixed
  `q` = so_test_message_cascade_mixed
  property `recipient`
  property `recipientID`
  property `sender`
  property `senderID`
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_ForeignKey_cascade.SOTestMessageCascadeMixed`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'so_test_message_cascade_mixed'

class `sqlobject.tests.test_ForeignKey_cascade.` `SOTestMessageCascadeNull`(**kw)

  Bases: `sqlobject.main.SQLObject`

  property `body`
  `j` = so_test_message_cascade_null
  `q` = so_test_message_cascade_null
  property `recipient`
  property `recipientID`
  property `sender`
  property `senderID`
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_ForeignKey_cascade.SOTestMessageCascadeNull`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'so_test_message_cascade_null'

class `sqlobject.tests.test_ForeignKey_cascade.` `SOTestMessageCascadeTrue`(**kw)

  Bases: `sqlobject.main.SQLObject`

  property `body`
  `j` = so_test_message_cascade_true
  `q` = so_test_message_cascade_true
  property `recipient`
  property `recipientID`
  property `sender`
  property `senderID`
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_ForeignKey_cascade.SOTestMessageCascadeTrue`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'so_test_message_cascade_true'

class `sqlobject.tests.test_ForeignKey_cascade.` `SOTestPerson1`(**kw)

  Bases: `sqlobject.main.SQLObject`

  `j` = so_test_person1
  property `name`
  `q` = so_test_person1
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_ForeignKey_cascade.SOTestPerson1`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'so_test_person1'

class `sqlobject.tests.test_ForeignKey_cascade.` `SOTestPerson2`(**kw)

  Bases: `sqlobject.main.SQLObject`

  `j` = so_test_person2
  property `name`
  `q` = so_test_person2
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_ForeignKey_cascade.SOTestPerson2`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'so_test_person2'

class `sqlobject.tests.test_ForeignKey_cascade.` `SOTestPerson3`(**kw)

  Bases: `sqlobject.main.SQLObject`

  `j` = so_test_person3
  property `name`
  `q` = so_test_person3
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_ForeignKey_cascade.SOTestPerson3`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'so_test_person3'

class `sqlobject.tests.test_ForeignKey_cascade.` `SOTestPerson4`(**kw)

  Bases: `sqlobject.main.SQLObject`

  `j` = so_test_person4
  property `name`
  `q` = so_test_person4
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_ForeignKey_cascade.SOTestPerson4`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'so_test_person4'

`sqlobject.tests.test_ForeignKey_cascade.` `test1`()

`sqlobject.tests.test_ForeignKey_cascade.` `test2`()

`sqlobject.tests.test_ForeignKey_cascade.` `test3`()

`sqlobject.tests.test_ForeignKey_cascade.` `test4`()

`sqlobject.tests.test_ForeignKey_cascade.` `test5`()